VERSION 8000; ; 8300
* -----------------------------------------------------------------------------
* @filedoc
* @file Topo_LinienAusProfillinie.CSX
* @brief Bsp. fr Linienerzeugung aus Profillinie 
* 
* Beispiel: Topografielinien aus einer Profillinie generieren.
* Fr alle Profilpunkte werden Lagekoordinaten berechnet und als sttzpunktfreie Linie gespeichert. 
* Hinweis: Bei Punkten mit gleichen T-Werten wird nur der erste Punkt gespeichert (Linienelement htte sonst Lnge = 0)!
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author JH
* @endfiledoc
* -----------------------------------------------------------------------------
*       1 14.05.09 JH Version fr die 8.3 hergestellt
* @history
* -----------------------------------------------------------------------------

* Vereinbarungen ---------------------------------------------------------------

BILDSCHIRM GRAFIK                  | gibt die Meldungen im Arbeitsprotokoll aus

* Zuweisungen ------------------------------------------------------------------

PLinNr = 10                        | Nummer der Profillinie
AchsNr = ACHS_WAHL(0)              | Auswahl der Achse im Dialog
!Schicht = "Profillinien"          | Name der Schicht

* Deklarationen ----------------------------------------------------------------

* Systemobjekte
SYMBOLE /XSECTIONSYS/ XsectionSys             | Symbol fr das System der Querprofile
SYMBOLE /TOPOSYS/ TopoSys                     | Symbol fr das System der Topografiedaten
* Querprofilobjekte
SYMBOLE /XSECTION/ Querschnitt                | Symbol fr den Querschnitt
SYMBOLE /XsectionLine/ QLinie                 | Symbol fr die Profillinie
SYMBOLE /XsectionPoint/ QPunkt                | Symbol fr den Profilpunkz
* Topografieojekte
SYMBOLE /TOPOLAYER/ Schicht                   | Symbol fr die Schicht
SYMBOLE /TOPOLINE/ TopoLinie                  | Symbol fr die Topografielinie
SYMBOLE /TOPOLINEELEMENT/ TopoElement         | Symbol fr das Linienelement
* Hilfsobjekte
SYMBOLE /LINE/ HLinie                         | Symbol fr die Hilfslinie
SYMBOLE /COORDINATE/ HPunkt                   | Symbol fr den Hilfspunkt

* Ausfhrungen ------------------------------------------------------------

* Systemobjekte
XsectionSys = Project.GetXSectionSys(AchsNr)  | liefert das Objekt fr das System der Querprofile einer Achse
TopoSys = Project.GetTopoSys()                | liefert das Objekt fr das System der Topografiedaten  

* Schichtobjekt 
Schicht = TopoSys.GetLayerByName(!Schicht)    | liefert die vorhandene Schicht
WENN Schicht == $NULL DANN                    | Wenn Schicht nicht vorhanden, wird eine neue Schicht angelegt
  Schicht = TopoSys.CreateLayer(!Schicht)
SONST                                         | Wenn Schicht vorhanden, werden alle Topografielinien gelscht
  TopoSys.ClearLines(Schicht)
WEITER

* Querschnittobjekt
Querschnitt = $NULL                                            | Querschnitt auf Null setzen
Last_QT = 0                                                    | letzter T-Wert                                             

SOLANGE Querschnitt = XsectionSys.GetNextXSection(Querschnitt) | liest die Querschnitte fortlaufend aus

  Station = Querschnitt.GetChainage()                          | liefert den Stationswert des Querschnittes
  * Profillinienobjekt
  QLinie = Querschnitt.GetLine(PLinNr)                         | liefert die vorhandene Profillinie des Querschnitts
  WENN QLinie <> $NULL DANN
    PPktAnz = QLinie.GetPointCount()                           | liefert die Anzahl der Profillinienpunkte
    * Topografielinienobjekt
    TopoLinie = TopoSys.CreateLine(Schicht; PLinNr)            | erzeugt eine neue Topografielinie
    * Schleife zur Erzeugung der Topografielinie ber alle Punkte der Profillinie
    SCHLEIFE  I = 1; PPktAnz
      * Profilpunktobjekt
      QPunkt = QLinie.GetPoint(I)                              | liefert einen Profilpunkt ber den Index
      QP_T = QPunkt.GetT()                                     | liefert den T-Wert des Profilpunktes
      WENN QP_T == Last_QT DANN                                 
        MELDE "PunktId # und PunktId # haben an der Station #.## den gleichen T-Wert --> Linienelement wird nicht generiert!"; I; i-1; Station
      WEITER 
      QP_Z = QPunkt.GetZ()                                     | liefert den Z-Wert des Profilpunktes
      * Hilfspunktobjekt
      HPunkt = Querschnitt.GetLateralCoordinate(QP_T)          | liefert fr den T-Wert des Profilpunktes die Lagekoordinate 
      HPunkt.SetZ(QP_Z)                                        | setzt den Z-Wert                                         
      HPunkt.Draw(7; 8)                                        | zeichnet den Hilfspunkt in der Lageansicht
      TopoLinie.AddCoordinate(HPunkt)                          | fgt die Koordinate und Hhe des Hilfspunktes in die Topografielinie ein
      Last_QT = QP_T
    ENDE SCHLEIFE
  WEITER

ENDE SOLANGE